@@ -172,7 +172,7 @@ def _writeModuleParamField(module, NewParamValueDictionary, hubName):
         data = (parmString, module)
         db.query_rowcount(sql, data)
 
-def _writeTempalteParamField(template, NewParamValueDictionary, hubName):
+def _writeTemplateParamField(template, NewParamValueDictionary, hubName):
         """
         Take a dictionary, transform it to properly formatted params string for Joomla, and 
         update the params field of the jos_template_styles table for the specified template
@@ -189,7 +189,7 @@ def _writeTempalteParamField(template, NewParamValueDictionary, hubName):
         else:
 		raise Exception
 
-        data = (parmString, tempalte)
+        data = (parmString, template)
         db.query_rowcount(sql, data)
 
 
@@ -340,7 +340,7 @@ def _buildTemplateDictionary(template, hubName):
         # look up parm string and parse it on newline, for each line, parse it further based on *first* '='
         sql = "SELECT `params` from jos_template_styles WHERE template=%s"
 
-        data = (module)
+        data = (template)
         paramsString = db.query_selectscalar(sql,template)
 
         if hubzero.utilities.misc.JOOMLA_25 and paramsString.startswith('{'):
@@ -448,7 +448,7 @@ def addTemplateParam(template, parameterName, parameterValue, allowOverwrite=Tru
                 else:
                         paramDict[parameterName] = parameterValue
 
-        _writeTemplateParamField(module, paramDict, hubName)
+        _writeTemplateParamField(template, paramDict, hubName)
 
 	
 def delComponentParam(componentOption, parameterName, hubName = ""):
