@@ -432,7 +432,7 @@ def addhubuser(hubname,
 		return(3)
 
 	# if the user doesn't want custom group for this user, they still need to be added to some group
-	if not skipCreateGroup:
+	if skipCreateGroup:
 		gidNumber = 100 # default to the users group
 		gid = 'users'
 
